@@ -1,11 +1,12 @@
+import contextlib
 import json
 
 from hashfs import HashFS
 from pydantic.dataclasses import dataclass
 
-from typing import List, Type, TypeVar, Generic
+from typing import List, Type, TypeVar, Generic, Generator
 
-from .registerable import Registerable
+from .registerable import Registerable, Serializable
 
 T = TypeVar('T', bound=Registerable)
 
@@ -34,3 +35,18 @@ class Registry(Generic[T]):
                     raise ValueError(f'Not a recognized class: {class_title} ({known_classes})')
             except KeyError:
                 raise ValueError(f'Not a serialized object: {hash_str}')
+
+
+DeserializedBase = TypeVar('DeserializedBase')
+
+
+class SerializableRegistry(Generic[DeserializedBase], Registry[Serializable[DeserializedBase]]):
+
+    @contextlib.contextmanager
+    def open(self, hash_str: str) -> Generator[DeserializedBase, None, None]:
+        serialized = self.load(hash_str)
+        deserialized = serialized.unpack(self.fs)
+        try:
+            yield deserialized
+        finally:
+            serialized.close(deserialized)
